pbose
=====

.. image:: https://img.shields.io/pypi/v/pbose.svg
    :target: https://pypi.python.org/pypi/pbose
    :alt: Latest PyPI version

Protobuf Object Signing and Encryption.

Usage
-----

Installation
------------
